@@ -1,4 +1,4 @@
-## ---- cache = FALSE, include=FALSE--------------------------------------------
+## ----cache = FALSE, include=FALSE---------------------------------------------
 knitr::opts_chunk$set(collapse = T, comment = "#>", 
                       fig.width = 6, fig.height = 4, fig.align = "center")
 
@@ -7,18 +7,18 @@ library(quantities)
 
 iris.q <- iris
 for (i in 1:4)
-  quantities(iris.q[,i]) <- list("cm", iris.q[,i] * 0.05)
+  quantities(iris.q[,i]) <- list("cm", iris.q[,i] * 0.02)
 head(iris.q)
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  rownames(installed.packages(priority="base"))
 
-## ---- echo=FALSE--------------------------------------------------------------
+## ----echo=FALSE---------------------------------------------------------------
 print(c("base", "compiler", "datasets", "graphics", "grDevices", "grid", "methods", "parallel", "splines", "stats", "stats4", "tcltk", "tools", "utils"))
 
 ## -----------------------------------------------------------------------------
-iris.q[which(iris.q$Sepal.Length > set_quantities(7.5, cm)), ]
-subset(iris.q, Sepal.Length > set_quantities(7.5, cm))
+iris.q[which(iris.q$Sepal.Length > set_quantities(75, mm)), ]
+subset(iris.q, Sepal.Length > set_quantities(75, mm))
 
 ## -----------------------------------------------------------------------------
 iris.q$Sepal.Length[1:5]
@@ -105,19 +105,55 @@ head(wide.2)
 ## -----------------------------------------------------------------------------
 all(sapply(colnames(iris.q), function(col) all(iris.q[[col]] == wide.2[[col]])))
 
-## ---- cache = FALSE, include=FALSE--------------------------------------------
+## ----cache = FALSE, include=FALSE---------------------------------------------
+required <- c(
+  packageVersion("errors") >= "0.3.6.1",
+  packageVersion("units") >= "0.8-0"
+)
+
+if (!all(required))
+  knitr::opts_chunk$set(eval = FALSE)
+
+## -----------------------------------------------------------------------------
+# vector plots
+with(iris.q, plot(Sepal.Width, col=Species))
+
+## ----eval=FALSE---------------------------------------------------------------
+#  # x-y plots
+#  with(iris.q, plot(Sepal.Length, Sepal.Width, col=Species))
+#  # dataframe plots
+#  plot(iris.q[, c("Sepal.Length", "Sepal.Width")], col=iris.q$Species)
+
+## -----------------------------------------------------------------------------
+plot(Sepal.Width ~ Sepal.Length, iris.q, col=Species)
+
+## -----------------------------------------------------------------------------
+plot(as.numeric(Sepal.Width) ~ Sepal.Length, iris.q, col=Species)
+
+## -----------------------------------------------------------------------------
+plot(Sepal.Width ~ as.numeric(Sepal.Length), iris.q, col=Species)
+
+## -----------------------------------------------------------------------------
+plot(Sepal.Width ~ set_quantities(as.numeric(Sepal.Length), 1, 0), iris.q, col=Species)
+
+## ----cache = FALSE, include=FALSE---------------------------------------------
 required <- c("dplyr", "tidyr")
 
+knitr::opts_chunk$set(eval = TRUE)
 if (!all(sapply(required, requireNamespace, quietly = TRUE)))
   knitr::opts_chunk$set(eval = FALSE)
 
-## ---- message=FALSE, warning=FALSE--------------------------------------------
+## ----message=FALSE, warning=FALSE---------------------------------------------
 library(dplyr); packageVersion("dplyr")
 library(tidyr); packageVersion("tidyr")
 
+## -----------------------------------------------------------------------------
+iris.q <- as_tibble(iris.q)
+head(iris.q)
+
 ## -----------------------------------------------------------------------------
 iris.q %>%
-  filter(Sepal.Length > set_quantities(7.5, cm)) %>%
+  filter(Sepal.Length > set_quantities(75, mm)) %>%
   head()
 
 ## -----------------------------------------------------------------------------
@@ -134,14 +170,8 @@ iris.q %>%
   ) %>%
   head()
 
-## ---- error=TRUE--------------------------------------------------------------
-iris.q %>%
-  group_by(Species) %>%
-  summarise_all(mean)
-
 ## -----------------------------------------------------------------------------
 iris.q %>%
-  mutate_at(vars(-Species), drop_errors) %>%
   group_by(Species) %>%
   summarise_all(mean)
 
@@ -155,28 +185,45 @@ iris.q %>%
 
 ## -----------------------------------------------------------------------------
 iris.q %>%
-  gather("key", "value", 1:4) %>%
-  separate(key, c("part", "dim")) %>%
+  pivot_longer(1:4) %>%
+  separate(name, c("part", "dim")) %>%
   head()
 
 ## -----------------------------------------------------------------------------
-wide <- iris %>%
+iris %>%
   # first gather, with row numbers as row_id
   mutate(row_id = 1:n()) %>%
-  gather("key", "value", 1:4) %>%
-  separate(key, c("part", "dim")) %>%
+  pivot_longer(1:4) %>%
   # assign quantities
   mutate(value = set_quantities(value, cm, value * 0.05)) %>%
-  # now spread
-  unite(key, part, dim, sep=".") %>%
-  spread(key, value) %>%
-  select(-row_id)
+  # now spread and remove the row_id
+  pivot_wider() %>%
+  select(-row_id) %>%
+  head()
 
-head(wide)
+## ----cache = FALSE, include=FALSE---------------------------------------------
+required <- c(
+  packageVersion("errors") >= "0.3.6.1",
+  packageVersion("units") >= "0.8-0"
+)
 
-## ---- error=TRUE--------------------------------------------------------------
-all(sapply(colnames(iris.q), function(col) all(iris.q[[col]] == wide[[col]])))
+if (!all(required))
+  knitr::opts_chunk$set(eval = FALSE)
 
-length(errors(iris.q$Sepal.Length))
-length(errors(wide$Sepal.Length))
+## ----message=FALSE, warning=FALSE---------------------------------------------
+library(ggplot2); packageVersion("ggplot2")
+
+## -----------------------------------------------------------------------------
+p0 <- ggplot(iris.q) + aes(Sepal.Length, Sepal.Width, color=Species) +
+  geom_point()
+p0
+
+## -----------------------------------------------------------------------------
+p0 + geom_errors()
+
+## -----------------------------------------------------------------------------
+p0 + geom_errors(aes(x=drop_errors(Sepal.Length)))
+
+## -----------------------------------------------------------------------------
+p0 + geom_errors() + scale_x_units(unit="mm") + scale_y_units(unit="m")
 
